@@ -1,3 +1,4 @@
+from enum import Enum
 from typing import Final
 
 from httpx import Timeout
@@ -20,3 +21,19 @@ ANDROID_HEADER: Final[dict[str, str]] = {
 COMMON_TIMEOUT: Final[Timeout] = Timeout(connect=15.0, read=20.0, write=10.0, pool=10.0)
 
 DOWNLOAD_TIMEOUT: Final[Timeout] = Timeout(connect=15.0, read=240.0, write=10.0, pool=10.0)
+
+
+class PlatformEnum(str, Enum):
+    ACFUN = "acfun"
+    BILIBILI = "bilibili"
+    DOUYIN = "douyin"
+    KUAISHOU = "kuaishou"
+    NGA = "nga"
+    TIKTOK = "tiktok"
+    TWITTER = "twitter"
+    WEIBO = "weibo"
+    XIAOHONGSHU = "xiaohongshu"
+    YOUTUBE = "youtube"
+
+    def __str__(self) -> str:
+        return self.value
