@@ -1,6 +1,8 @@
 # 导出所有 Parser 类
-from .acfun import AcfunParser as AcfunParser  # noqa: I001
+from ..download import YTDLP_DOWNLOADER
+from .acfun import AcfunParser as AcfunParser
 from .base import BaseParser as BaseParser
+from .bilibili import BilibiliParser as BilibiliParser
 from .data import ParseResult as ParseResult
 from .douyin import DouyinParser as DouyinParser
 from .kuaishou import KuaiShouParser as KuaiShouParser
@@ -8,9 +10,6 @@ from .nga import NGAParser as NGAParser
 from .twitter import TwitterParser as TwitterParser
 from .weibo import WeiBoParser as WeiBoParser
 from .xiaohongshu import XiaoHongShuParser as XiaoHongShuParser
-from .bilibili import BilibiliParser as BilibiliParser
-
-from ..download import YTDLP_DOWNLOADER
 
 if YTDLP_DOWNLOADER is not None:
     from .tiktok import TikTokParser as TikTokParser
