@@ -1,10 +1,11 @@
 """Parser 基类定义"""
 
-from abc import ABC, abstractmethod
+from abc import ABC
 from asyncio import Task
+from collections.abc import Callable, Coroutine
 from pathlib import Path
-import re
-from typing import ClassVar
+from re import Match, Pattern, compile
+from typing import TYPE_CHECKING, Any, ClassVar, TypeVar, cast
 from typing_extensions import Unpack
 
 from ..config import pconfig as pconfig
@@ -18,24 +19,45 @@ from ..exception import SizeLimitException as SizeLimitException
 from ..exception import ZeroSizeException as ZeroSizeException
 from .data import ParseResult, ParseResultKwargs, Platform
 
+T = TypeVar("T", bound="BaseParser")
+HandlerFunc = Callable[[T, Match[str]], Coroutine[Any, Any, ParseResult]]
+KeyPatterns = list[tuple[str, Pattern[str]]]
 
-class BaseParser(ABC):
+_KEY_PATTERNS = "_key_patterns"
+
+
+# 注册处理器装饰器
+def handle(keyword: str, pattern: str):
+    """注册处理器装饰器"""
+
+    def decorator(func: HandlerFunc[T]) -> HandlerFunc[T]:
+        if not hasattr(func, _KEY_PATTERNS):
+            setattr(func, _KEY_PATTERNS, [])
+
+        key_patterns: KeyPatterns = getattr(func, _KEY_PATTERNS)
+        key_patterns.append((keyword, compile(pattern)))
+
+        return func
+
+    return decorator
+
+
+class BaseParser:
     """所有平台 Parser 的抽象基类
 
     子类必须实现：
-    - platform: 平台信息（包含名称和显示名称）
-    - patterns: URL 正则表达式模式列表
-    - parse: 解析 URL 的方法（接收正则表达式对象）
+    - platform: 平台信息（包含名称和显示名称)
     """
 
-    # 类变量：存储所有已注册的 Parser 类
     _registry: ClassVar[list[type["BaseParser"]]] = []
+    """ 存储所有已注册的 Parser 类 """
 
     platform: ClassVar[Platform]
     """ 平台信息（包含名称和显示名称） """
 
-    patterns: ClassVar[list[tuple[str, str]]]
-    """ URL 正则表达式模式列表 [(keyword, pattern), ...] """
+    if TYPE_CHECKING:
+        _key_patterns: ClassVar[KeyPatterns]
+        _handlers: ClassVar[dict[str, HandlerFunc]]
 
     def __init__(self):
         self.headers = COMMON_HEADER.copy()
@@ -49,39 +71,65 @@ class BaseParser(ABC):
         if ABC not in cls.__bases__:  # 跳过抽象类
             BaseParser._registry.append(cls)
 
+        cls._handlers = {}
+        cls._key_patterns = []
+
+        # 获取所有被 handle 装饰的方法
+        for attr_name in dir(cls):
+            attr = getattr(cls, attr_name)
+            if callable(attr) and hasattr(attr, _KEY_PATTERNS):
+                key_patterns: KeyPatterns = getattr(attr, _KEY_PATTERNS)
+                handler = cast(HandlerFunc, attr)
+                for keyword, pattern in key_patterns:
+                    cls._handlers[keyword] = handler
+                    cls._key_patterns.append((keyword, pattern))
+
+        # 按关键字长度降序排序
+        cls._key_patterns.sort(key=lambda x: -len(x[0]))
+
     @classmethod
     def get_all_subclass(cls) -> list[type["BaseParser"]]:
         """获取所有已注册的 Parser 类"""
         return cls._registry
 
-    @abstractmethod
-    async def parse(self, keyword: str, searched: re.Match[str]) -> ParseResult:
-        """解析 URL 获取内容信息并下载资源
+    async def parse(self, keyword: str, searched: Match[str]) -> ParseResult:
+        """解析 URL 提取信息
 
         Args:
             keyword: 关键词
             searched: 正则表达式匹配对象，由平台对应的模式匹配得到
 
         Returns:
-            ParseResult: 解析结果（已下载资源，包含 Path)
+            ParseResult: 解析结果
 
         Raises:
             ParseException: 解析失败时抛出
         """
-        raise NotImplementedError
+        return await self._handlers[keyword](self, searched)
+
+    async def parse_with_redirect(
+        self,
+        url: str,
+        headers: dict[str, str] | None = None,
+    ) -> ParseResult:
+        """先重定向再解析"""
+        redirect_url = await self.get_redirect_url(url, headers=headers or self.headers)
+
+        if redirect_url == url:
+            raise ParseException(f"无法重定向 URL: {url}")
+
+        keyword, searched = self.search_url(redirect_url)
+        return await self.parse(keyword, searched)
 
     @classmethod
-    def search_url(cls, url: str) -> tuple[str, re.Match[str]]:
-        from nonebot import logger
-
+    def search_url(cls, url: str) -> tuple[str, Match[str]]:
         """搜索 URL 匹配模式"""
-        for keyword, pattern in cls.patterns:
+        for keyword, pattern in cls._key_patterns:
             if keyword not in url:
                 continue
-            if searched := re.search(pattern, url):
+            if searched := pattern.search(url):
                 return keyword, searched
-            logger.debug(f"keyword '{keyword}' is in '{url}', but not matched")
-        raise ValueError(f"无法匹配 {url}")
+        raise ParseException(f"无法匹配 {url}")
 
     @classmethod
     def result(cls, **kwargs: Unpack[ParseResultKwargs]) -> ParseResult:
@@ -93,7 +141,7 @@ class BaseParser(ABC):
         url: str,
         headers: dict[str, str] | None = None,
     ) -> str:
-        """获取重定向后的URL"""
+        """获取重定向后的 URL, 单次重定向"""
         from httpx import AsyncClient
 
         headers = headers or COMMON_HEADER.copy()
@@ -108,6 +156,26 @@ class BaseParser(ABC):
                 response.raise_for_status()
             return response.headers.get("Location", url)
 
+    @staticmethod
+    async def get_final_url(
+        url: str,
+        headers: dict[str, str] | None = None,
+    ) -> str:
+        """获取重定向后的 URL, 允许多次重定向"""
+        from httpx import AsyncClient
+
+        headers = headers or COMMON_HEADER.copy()
+        async with AsyncClient(
+            headers=headers,
+            verify=False,
+            follow_redirects=True,
+            timeout=COMMON_TIMEOUT,
+        ) as client:
+            response = await client.get(url)
+            if response.status_code >= 400:
+                response.raise_for_status()
+            return str(response.url)
+
     def create_author(
         self,
         name: str,
@@ -146,8 +214,11 @@ class BaseParser(ABC):
         """创建图片内容列表"""
         from .data import ImageContent
 
-        img_tasks = [DOWNLOADER.download_img(url, ext_headers=self.headers) for url in image_urls]
-        return [ImageContent(task) for task in img_tasks]
+        contents: list[ImageContent] = []
+        for url in image_urls:
+            task = DOWNLOADER.download_img(url, ext_headers=self.headers)
+            contents.append(ImageContent(task))
+        return contents
 
     def create_dynamic_contents(
         self,
@@ -156,8 +227,11 @@ class BaseParser(ABC):
         """创建动态图片内容列表"""
         from .data import DynamicContent
 
-        dynamic_tasks = [DOWNLOADER.download_video(url, ext_headers=self.headers) for url in dynamic_urls]
-        return [DynamicContent(task) for task in dynamic_tasks]
+        contents: list[DynamicContent] = []
+        for url in dynamic_urls:
+            task = DOWNLOADER.download_video(url, ext_headers=self.headers)
+            contents.append(DynamicContent(task))
+        return contents
 
     def create_audio_content(
         self,
